﻿© Fluke. All Rights Reserved.                               MET/CAL Procedure
=============================================================================
INSTRUMENT:            Sub Compute Power Splitter Leveling Uncertainty
DATE:                  2010-10-11
AUTHOR:                Fluke Calibration
REVISION:              $Revision: 2619 $
ADJUSTMENT THRESHOLD:  70%
NUMBER OF TESTS:       1
NUMBER OF LINES:       75
=============================================================================
#
#  Procedure Author:
#        DFM
#
#  Model(s) Covered:
#        Anytime a power splitter is used to perform external leveling
#
#  Compatibility:
#        MET/CAL 7.3.19 or later
#
#  Subprocedures:
#        Sub Compute Mismatch Uncertainty (%)
#
#  Required Files:
#        Applicable power meter accuracy file
#        Applicable power splitter accuracy file
#
#  Additional Equipment Required:
#        None
#
#  Example:
# 1.001  MATH         @DevName1       = "Agilent E4418B"
# 1.002  MATH         @SensorAccMode  = "Watts 100mW F64"
# 1.003  MATH         @SensorSWR_Mode = "SWR 8485A"
# 1.004  MATH         @DevName2       = "Agilent 11667B"
# 1.005  MATH         @SpltrSWR_Mode  = "Output SWR"
# 1.006  MATH         @SpltrTrackMode = "Tracking"
# 1.007  MATH         @UUT_SWR        = 1.2
# 1.008  CALL         Sub Compute Power Splitter Leveling Uncertainty
# 1.009  MATH         L[1]            = @LevelUncPct
#
#  The copyright for this procedure is owned by Fluke Corporation.
#
 STEP    FSC    RANGE NOMINAL        TOLERANCE     MOD1        MOD2  3  4 CON

# Retrieve linear power level; specify mode string for accuracy look-up.
  1.001  MATH         PwrLin = DBMTOW(MEM); AccMode = @SensorAccMode
# Compute normalized power measurement uncertainty (%), Port 1.
  1.002  MATH         PwrAccLin = ACCV2(@DevName1, AccMode, PwrLin, @TestFreq)
  1.003  MATH         L[1] = ((PwrAccLin / CONF(@DevName1)) / PwrLin) * 100
# Retrieve power sensor input SWR at test frequency.
  1.004  MATH         @LoadSWR = ACCV(@DevName1, @SensorSWR_Mode, @TestFreq)
# Retrieve Power Splitter (output port) SWR at test frequency.
  1.005  MATH         @SourceSWR = ACCV(@DevName2, @SpltrSWR_Mode, @TestFreq)
# Compute normalized mismatch uncertainty (Splitter to Sensor), Port 1.
  1.006  CALL         Sub Compute Mismatch Uncertainty (%)
  1.007  MATH         L[2] = @MismatchUncPct
  1.008  MATH         @LoadSWR = @UUT_SWR
# Compute normalized mismatch uncertainty (Splitter to UUT), Port 2.
  1.009  CALL         Sub Compute Mismatch Uncertainty (%)
  1.010  MATH         L[3] = @MismatchUncPct
# Retrieve Power Splitter tracking error (dB) at test frequency.
  1.011  MATH         L[4] = ACCV(@DevName2, @SpltrTrackMode, @TestFreq)
# Convert tracking error (dB) to percent and normalize.
  1.012  MATH         L[4] = DBTOPCTW_D(L[4]) / SQRT(3)
# Flatness uncertainty computed based on power measurement uncertainty,
# mismatch uncertainty between power splitter and UUT, power splitter and
# power sensor, and power splitter tracking error.
  1.013  MATH         @LevelUncPct = RSS_L(1, 4)

  1.014  END
