﻿© Fluke Corporation. All Rights Reserved.                   MET/CAL Procedure
=============================================================================
INSTRUMENT:            Sub HP/Agilent E441x Cal Factor Utility IEEE
DATE:                  2011-01-20
AUTHOR:                Fluke
REVISION:              $Revision: 2619 $
ADJUSTMENT THRESHOLD:  70%
NUMBER OF TESTS:       1
NUMBER OF LINES:       243
CONFIGURATION:         Agilent E4419B
=============================================================================
#
#  Procedure Author:
#        DAC, DFM
#
#  Model(s) Covered:
#        EPM-441A, EPM-442A, E4418A/B, E4419A/B
#
#  Source:
#        HP EPM-441A/442A Power Meters Programming Guide, HP Part No.
#        E4418-90025, March 1998
#
#        Agilent Technologies E4418B/E4419B Power Meters Programming Guide,
#        Part No. E4418-90029, November 2008
#
#  Compatibility:
#        MET/CAL 7.20 SP2 (7.20T) or later
#
#  Subprocedure(s):
#        Sub EPM-series Review Cal Factors IEEE
#        Sub EPM-series Enter Cal Factors IEEE
#        Sub EPM-series Delete Cal Factors IEEE
#        Sub EPM-series Rename Cal Factors IEEE
#
#  The Procedure was tested using:
#
#        Model No.    : E4419A
#        Serial No.   : US38260572
#        Options      : None
#        Firmware Rev.: A2.09.01
#
#  Additional Information
#
#     Cal Factor Table Contents:
#
#        The cal factor table has the following format:
#
#          Frequency         Cal Factors
#        --------------   ----------------
#              --          ref cal factor
#         frequency 1       cal factor 1
#         frequency 2       cal factor 2
#         frequency 3       cal factor 3
#             .                  .
#             .                  .
#         frequency n       cal factor n
#
#        The following rules apply:
#
#        o RF Frequency Range:              1 kHz - 999.9 GHz RF Frequency
#        o Frequency Resolution:            1 kHz
#        o Cal Factor Range:                1-150%
#        o Cal Factor Resolution:           0.1%
#        o Maximum number of entries/table: 80 (frequency), 81 (cal factor)
#
#        o Due to the required entry of the reference cal factor, the number
#        o of frequency points must be one less than the number of cal factor
#          points.  This is verified when the sensor calibration table is
#          selected.
#        o The frequency/cal factor data must be entered in order of ascending
#          frequency.
#        o All frequencies are truncated to a multiple of 1 kHz.
#
#     Cal Factor Table Name:
#
#        o The table name cannot exceed 12 characters, maximum.
#        o Only characters A to Z (upper case), a to z (lower case), 0 - 9,
#          or "_" (underscore) are allowed.
#        o Multiple tables of the same name are not allowed.
#
#  NOTE: This procedure has no explict error checking of 441x remote commands.
#  When used with MET/CAL 7.0 or later, configuring an E4418A/B or E4419A/B
#  establishes the alias 441x.  If a command in an IEEE/SCPI FSC in this
#  procedure causes an error, it is caught by the SRQ handler in the MET/CAL
#  441x driver.
#
 STEP    FSC    RANGE NOMINAL        TOLERANCE     MOD1        MOD2  3  4 CON

  1.001  HEAD         HP/AGILENT E441x() CAL FACTOR UTILITY
  1.002  HEAD         -2 Operational Information
  1.003  DISP         This utility supports the review, entry, deletion, or
  1.003  DISP         renaming of calibration factor table/data for hardware
  1.003  DISP         supported models of HP/Agilent power sensors.
  1.003  DISP
  1.003  DISP         Supported models of power sensors are:
  1.003  DISP
  1.003  DISP         [32]- 8480() Series power sensors
  1.003  DISP         [32]- N8480() Series power sensors with Option CFT
  1.003  DISP
  1.003  DISP         This utility may be used for both 1 and 2 channel power
  1.003  DISP         meters.

  1.004  DO
  1.005  HEAD         -2 Cal Factor Selection
  1.006  SCPI         [@441x]MEMORY:CATALOG:TABLE?[I$]
  1.007  MATH         @Catalog = MEM2
# The first cal factor table name is in the third field of the catalog.
  1.008  MATH         Counter = 3

  1.009  MATH         Id = LBNEW("EPM-series Power Meter")
  1.010  MATH         LBTEXT(Id, "Select desired cal factor table.")
  1.011  MATH         LBCONF(Id, "+SelReq,+ok,+term,-border")

  1.012  WHILE        Counter < 63
# Extract table name, delete leading " from value, and add spaces for display.
  1.013  MATH         Table = "   " & SUB(FLD(@Catalog, Counter, ","), 2, 12)
  1.014  MATH         LBADD(Id, Table)
# Cal factor table names are specified in multiples of three until the last
# table (20) is reached in the 63rd field.
  1.015  MATH         Counter = Counter + 3
  1.016  ENDW

  1.017  MATH         LBBUTTON(Id, "Continue")
  1.018  MATH         LBBUTTON(Id, "Exit")
  1.019  MATH         Proceed = LBSHOW(Id)

  1.020  IF           Proceed > 1
  1.021  IEEE         [@441x]*RST;*OPC?[I!]
  1.022  END

  1.023  ELSE

  1.024  HEAD         -2 Select Function
# Strip white spaces (added above) prior to storing variable data.
  1.025  MATH         @EPMCalFactorTable = STRIPL(LBGETSEL(Id, 1))
# Copy selected cal factor table into a more 'compact' local variable name.
  1.026  MATH         Table = @EPMCalFactorTable
  1.027  IEEE         [@441x]MEM:TABL:SEL "[V Table]"

  1.028  MATH         IdFunc = LBNEW(Table & " Cal Factor Table")
  1.029  MATH         LBTEXT(IdFunc, "Select desired CF table action.")
  1.030  MATH         LBBUTTON(IdFunc, "Review")
  1.031  MATH         LBBUTTON(IdFunc, "Enter")
  1.032  MATH         LBBUTTON(IdFunc, "Delete")
  1.033  MATH         LBBUTTON(IdFunc, "Rename")
  1.034  MATH         LBBUTTON(IdFunc, "Cancel")
  1.035  MATH         Selection = LBSHOW(IdFunc)

  1.036  WHILE        Selection < 5

# ------- Cal Factor Review

  1.037  IF           Selection == 1
  1.038  CALL         Sub EPM-series Review Cal Factors IEEE

  1.039  IF           NOT(@EPMCalFactorsOk)
  1.040  OPBR         -z Do you wish to ENTER new values to the currently
  1.040  OPBR         selected sensor calibration table, "[V Table]"?
  1.040  OPBR
  1.040  OPBR         (Existing table data will be deleted.)

  1.041  IF           MEM1
  1.042  MATH         Selection = 2
  1.043  ENDIF

  1.044  ENDIF

  1.045  MATH         Selection = 5

# ------- Cal Factor Entry

  1.046  ELSEIF       Selection == 2

  1.047  DO
  1.048  CALL         Sub EPM-series Enter Cal Factors IEEE
  1.049  UNTIL        @EPMCalFactorsOk

  1.050  IF           NOT(@Abort)
  1.051  OPBR         -z Do you wish to REVIEW the Cal Factor data just
  1.051  OPBR         entered for sensor table "[V Table]"?

  1.052  IF           MEM1
  1.053  MATH         Selection = 1
  1.054  ENDIF

  1.055  ENDIF

  1.056  MATH         Selection = 5

# ------- Cal Factor Deletion

  1.057  ELSEIF       Selection == 3
  1.058  OPBR         -z Do you wish to DELETE the current contents of sensor
  1.058  OPBR         calibration table "[V Table]"?

  1.059  IF           MEM1
  1.060  CALL         Sub EPM-series Delete Cal Factors IEEE
  1.061  ENDIF

  1.062  MATH         Selection = 5

# ------- Cal Factor Table Rename

  1.063  ELSEIF       Selection == 4
  1.064  CALL         Sub EPM-series Rename Cal Factors IEEE
  1.065  MATH         Table = MEM2

  1.066  IF           NOT(@Abort)
  1.067  OPBR         -z Do you wish to REVIEW existing Cal Factor data for
  1.067  OPBR         sensor table "[V Table]"?

  1.068  IF           MEM1
  1.069  MATH         Selection = 1
  1.070  ELSE
  1.071  MATH         Selection = 5
  1.072  ENDIF

  1.073  ELSE

  1.074  DISP         Cal factor table renaming aborted!
  1.075  MATH         Selection = 5
  1.076  ENDIF

  1.077  ENDIF

  1.078  ENDW

  1.079  MATH         Selection = 5
  1.080  ENDIF        ; Cancel table selection

  1.081  OPBR         -z Are further REVIEW/ENTER/DELETE/RENAME cal factor
  1.081  OPBR         table operations required?
  1.081  OPBR
  1.081  OPBR         (Selecting "No" will exit the utility.)
  1.082  UNTIL        NOT(MEM1)

  1.083  HEAD
  1.084  IEEE         [@441x]*RST;*OPC?[I!]
  1.085  END
