﻿© Fluke. All Rights Reserved.                               MET/CAL Procedure
=============================================================================
INSTRUMENT:            Sub FSU Set Ref Level (dBm) /UWSG
DATE:                  2010-12-08
AUTHOR:                Fluke Calibration
REVISION:              $Revision: 2619 $
ADJUSTMENT THRESHOLD:  70%
NUMBER OF TESTS:       1
NUMBER OF LINES:       104
CONFIGURATION:         µW Signal Generator
=============================================================================
#
# Procedure Author:
#        DFM
#
# Model(s) Covered:
#        Agilent PSA series
#
# Compatibility:
#        MET/CAL 7.3.26 or later
#
# Subprocedures:
#        Sub Apply /UWSG
#        Sub FSU Take Sweep (MKPK)
#        Sub FSU Display Connection
#
# Required Files:
#        None
#
# Additional Equipment Required:
#        None
#
# The copyright for this procedure is owned by Fluke Corporation.
#
# The necessary parameters for this procedure are passed from the calling
# procedure.
#
#  @RefLvl     : The desired reference level as measured by the UUT (FSU).
#  @TestLvl    : The UWSG output level required to generate the specified
#                reference level.
#  @HiLimit    : The upper limit of the setting aperture (in dBm).
#  @LoLimit    : The lower limit of the setting aperture (in dBm).
#
#                (The UWSG output frequency is previously set in the calling
#                 procedure.)
#
# Example:
# 1.001  SCPI         CALC:MARK:Y?[I]
# 1.002  MATH         @RefLvl = 0; @TestLvl = -4
# 1.003  MATH         @LoLimit = @RefLvl - 0.05; @HiLimit = @RefLvl + 0.05
# 1.004  CALL         Sub FSU Set Ref Level (dBm) /UWSG
#
 STEP    FSC    RANGE NOMINAL        TOLERANCE     MOD1        MOD2  3  4 CON

  1.001  IF           0
  1.002  IEEE         [@UWSG]
  1.003  ENDIF

  1.004  MATH         MaxRetries = 5

  1.005  DO
  1.006  MATH         Count = 0; Retry = 1

  1.007  WHILE        ((MEM <= @LoLimit) || (MEM >= @HiLimit)) && Retry
  1.008  MATH         Delta = (@RefLvl - MEM)
  1.009  MATH         @TestLvl = @TestLvl + Delta
  1.010  MATH         @UWSG_Ampl = @TestLvl & "dBm"
  1.011  CALL         Sub Apply /UWSG
  1.012  CALL         Sub FSU Take Sweep (MKPK)
  1.013  SCPI         CALC:MARK:Y?[I]
  1.014  MATH         Count = Count + 1; Retry = (Count <= MaxRetries)
  1.015  ENDW

  1.016  MATH         @Error = (Count > (MaxRetries + 1))

  1.017  IF           @Error
  1.018  OPBR         -z Error: Unable to adjust µW Signal Generator output
  1.018  OPBR         [32]      level within its operating range to achieve
  1.018  OPBR         [32]      the desired test level ([V @RefLvl] dBm).
  1.018  OPBR
  1.018  OPBR         [32]      Verify UUT test requirements, UWSG output
  1.018  OPBR         [32]      limits, and connections prior to retrying,
  1.018  OPBR         [32]      if desired.
  1.018  OPBR
  1.018  OPBR         Do you wish to RETRY?
  1.018  OPBR
  1.018  OPBR         (Selecting "No" will cause the [V @TestName] test
  1.018  OPBR         to be terminated.)
  1.019  MATH         @Error = NOT(MEM1)

  1.020  IF           MEM1
  1.021  CALL         Sub FSU Display Connection
  1.022  MATH         @TestLvl = @RefLvl; MEM = @RefLvl
  1.023  ENDIF

  1.024  ENDIF

  1.025  UNTIL        ((MEM >= @LoLimit) && (MEM <= @HiLimit)) || @Error

  1.026  END
